==> showtime_1.0-2.tar.gz: showtime-1.0/src/defiles.cpp <==
#include <QObject>
#include <QMaemo5InformationBox>
#include <QFile>
#include <QDir>
#include <QDebug>
#include <QProcess>
#include <QTextStream>

#include "datadownloader.h"
#include "defiles.h"

DEFiles::DEFiles(QObject *parent) : DataDownloader(parent, "/opt/showtime/data/de/"), HELPERPATH("/opt/showtime/helper/")
{
	_settingsFile = new QFile(QString(DATAPATH) + ".de");
	initSettings();
}

void DEFiles::initSettings()
{
	// just call the parent init settings
	// nothing specific to DE(germany)
	DataDownloader::initSettings();
}

QUrl DEFiles::getUrl()
{
	QUrl url;

	QString requestChannelCode = _channelCodeMap[_requestChannel];

	if ( !_useLocal )
		url.setUrl(QString("http://tvprofil.net/xmltv/data/%2/%1_%2_tvprofil.net.xml?APP=SHOWTIME")
                                                            .arg(QDate::currentDate().toString("yyyy-MM-dd")).arg(requestChannelCode) );
	else
		url.setPath(QString(""));

	return url;
}

DEFiles::~DEFiles()
{
}

// better to call this after we process all channels requested so we dont 
// have to do file operatings after each channel download
void DEFiles::updateSettingsFile()
{
	QFile::remove(QString(DATAPATH) + ".de");

	_settingsFile->open(QIODevice::WriteOnly | QIODevice::ReadOnly);

	QTextStream s(_settingsFile);

	foreach(QString key, _channelDateMap.keys())	
	{
		s << "#" << key;
		foreach(QString date, _channelDateMap[key])
			s << '#' << date; 

		s << endl;
	}

	_settingsFile->close();
}

void DEFiles::checkDataStatus()
{
	// IF ( data is requested again on the same day  OR  data is requested for download on the same day again )
	// THEN dont do anything and use local file
	if ( _channelDateMap[_requestChannel].contains(_requestDate.toString("ddMMyyyy")) )
	{
		// file exists for today ( current date ) so no need to download again
		//qDebug() << "data for " << _requestChannel << " for date " << _requestDate << " exists";
		_useLocal = true;
	}
	else
	{
		// download the requested channel for the requested date
		_useLocal = false;
	}
}

QString DEFiles::finishedDownload(QString channel, QIODevice *source)
{
	QString filename = saveFile(channel, source);
	return filename;
}

QStringList DEFiles::getChannelList()
{
	QFile file(QString(DATAPATH) + ".de_channel_list");
	QStringList channellist;

	if (file.open(QIODevice::ReadOnly | QIODevice::Text))
	{
		QTextStream textStream(&file);
		
		while ( !textStream.atEnd() )
		{
			QStringList line = textStream.readLine().split('#');
			
			QString channelname = line[0];
			QString channelcode = line[1];

			_channelCodeMap[channelname] = channelcode;
		}

		return _channelCodeMap.keys();
	}
	
	return channellist;
}

void DEFiles::setInput(DownloadInput d)
{
	DataDownloader::setInput(d);
}

void DEFiles::sendRecordMsg(QStringList data)
{
}

void DEFiles::sentRecordMsg(int exitCode, QProcess::ExitStatus exitStatus)
{
}

==> showtime_1.0-7.tar.gz: showtime-1.0/src/defiles.cpp <==
#include <QObject>
#include <QMaemo5InformationBox>
#include <QFile>
#include <QDir>
#include <QDebug>
#include <QProcess>
#include <QTextStream>

#include "datadownloader.h"
#include "defiles.h"

DEFiles::DEFiles(QObject *parent) : DataDownloader(parent, "/opt/showtime/data/de/"), HELPERPATH("/opt/showtime/helper/")
{
	_settingsFile = new QFile(QString(DATAPATH) + ".de");
	initSettings();
}

void DEFiles::initSettings()
{
	// just call the parent init settings
	// nothing specific to DE(germany)
	DataDownloader::initSettings();
}

QUrl DEFiles::getUrl()
{
	QUrl url;

	QString requestChannelCode = _channelCodeMap[_requestChannel];

	if ( !_useLocal )
		url.setUrl(QString("http://tvprofil.net/xmltv/data/%2/%1_%2_tvprofil.net.xml?APP=SHOWTIME")
                                                            .arg(_requestDate.toString("yyyy-MM-dd")).arg(requestChannelCode) );
	else
		url.setPath(QString(""));

	return url;
}

DEFiles::~DEFiles()
{
}

// better to call this after we process all channels requested so we dont 
// have to do file operatings after each channel download
void DEFiles::updateSettingsFile()
{
	QFile::remove(QString(DATAPATH) + ".de");

	_settingsFile->open(QIODevice::WriteOnly | QIODevice::ReadOnly);

	QTextStream s(_settingsFile);

	foreach(QString key, _channelDateMap.keys())	
	{
		s << "#" << key;
		foreach(QString date, _channelDateMap[key])
			s << '#' << date; 

		s << endl;
	}

	_settingsFile->close();
}

void DEFiles::checkDataStatus()
{
	// IF ( data is requested again on the same day  OR  data is requested for download on the same day again )
	// THEN dont do anything and use local file
	if ( _channelDateMap[_requestChannel].contains(_requestDate.toString("ddMMyyyy")) )
	{
		// file exists for today ( current date ) so no need to download again
		//qDebug() << "data for " << _requestChannel << " for date " << _requestDate << " exists";
		_useLocal = true;
	}
	else
	{
		// download the requested channel for the requested date
		_useLocal = false;
	}
}

QString DEFiles::finishedDownload(QString channel, QIODevice *source)
{
	QString filename = saveFile(channel, source);
	return filename;
}

QStringList DEFiles::getChannelList()
{
	QFile file(QString(DATAPATH) + ".de_channel_list");
	QStringList channellist;

	if (file.open(QIODevice::ReadOnly | QIODevice::Text))
	{
		QTextStream textStream(&file);
		
		while ( !textStream.atEnd() )
		{
			QStringList line = textStream.readLine().split('#');
			
			QString channelname = line[0];
			QString channelcode = line[1];

			_channelCodeMap[channelname] = channelcode;
		}

		return _channelCodeMap.keys();
	}
	
	return channellist;
}

void DEFiles::setInput(DownloadInput d)
{
	DataDownloader::setInput(d);
}

void DEFiles::sendRecordMsg(QStringList data)
{
}

void DEFiles::sentRecordMsg(int exitCode, QProcess::ExitStatus exitStatus)
{
}
